import { makeAutoObservable, runInAction } from "mobx";
import { authInstance } from "@shared";

export type Route = {
  carrier: string;
  carrier_id: number;
  center_latitude: number;
  center_longitude: number;
  governor_appeal: number;
  id: number;
  path: number[][];
  rotate: number;
  route_direction: boolean;
  route_number: string;
  route_sys_number: string;
  scale_max: number;
  scale_min: number;
  video_preview: string;
};

class RouteStore {
  routes: {
    data: Route[];
    loaded: boolean;
  } = {
    data: [],
    loaded: false,
  };
  route: Record<string, Route> = {};

  constructor() {
    makeAutoObservable(this);
  }

  getRoutes = async () => {
    if (this.routes.loaded) return;
    const response = await authInstance.get("/route");

    runInAction(() => {
      this.routes = {
        data: response.data,
        loaded: true,
      };
    });
  };

  createRoute = async (route: any) => {
    const response = await authInstance.post("/route", route);
    const id = response.data.id;

    runInAction(() => {
      this.route[id] = { ...route, id };
      this.routes.data = [...this.routes.data, { ...route, id }];
    });
  };

  deleteRoute = async (id: number) => {
    await authInstance.delete(`/route/${id}`);

    runInAction(() => {
      this.routes = {
        data: this.routes.data.filter((route) => route.id !== id),
        loaded: true,
      };
    });
  };
}

export const routeStore = new RouteStore();
